### Title

Huangiu Scraper

### Descrption

* With huangiu Scraper you can scrape search results and extract the contents produced by the search result.
* In huangiu scraper it will scrape the data present of the website and give json data which contains the details of the contents on the website.
* It gives the every detail present inside website in the form of json data such as time of the news posted, article name etc.

### Run Scraper
```sh
from huangiu_scraper import *
link="https://finance.huanqiu.com/"
data=run_huangiu_scraper(link)
```

### How it works?
* It takes URL of huangiu page with a search keyword to scrape the data.
* It generates the json data which contains the information of the huangiu search result.


### Examples
Below are some of the examples of URLs using which you can scrape:

* [Example 1](https://tech.huanqiu.com/)

* [Example2](https://finance.huanqiu.com/)


### Queries/ Feedback
If you have some queries or feedback please contact us at following    
[Telegram](https://t.me/datakund)  
[Email](abhishek@datakund.com)









